dls-bxflow-epsic
=======================================================================

Bxflow beamline library for ePSIC.

Wraps core science algorithms as runnable tasks for workflow execution.

Also implements the filesystem naming conventions at the beamline.


.. toctree::
    :titlesonly:

    tutorials/index
    how-to/index
    explanations/index
    reference/index
